@@ -70,12 +70,12 @@ class LambdaToS3(
         :param id: - this is a a scope-unique id.
         :param bucket_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the bucket. Default: - S3_BUCKET_NAME
         :param bucket_permissions: Optional bucket permissions to grant to the Lambda function. One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
-        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket, providing both this and ``existingBucketObj`` will cause an error. Default: - Default props are used
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_bucket_obj: Optional - existing instance of S3 Bucket. If this is provided, then also providing bucketProps causes an error. Default: - None
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: Optional user provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         :param vpc_props: Properties to override default properties if deployVpc is true.
@@ -166,12 +166,12 @@ class LambdaToS3Props:
         '''
         :param bucket_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the bucket. Default: - S3_BUCKET_NAME
         :param bucket_permissions: Optional bucket permissions to grant to the Lambda function. One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
-        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket. Default: - Default props are used
+        :param bucket_props: Optional user provided props to override the default props for the S3 Bucket, providing both this and ``existingBucketObj`` will cause an error. Default: - Default props are used
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
-        :param existing_bucket_obj: Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error. Default: - None
-        :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_bucket_obj: Optional - existing instance of S3 Bucket. If this is provided, then also providing bucketProps causes an error. Default: - None
+        :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: Optional user provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param logging_bucket_props: Optional user provided props to override the default props for the S3 Logging Bucket. Default: - Default props are used
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         :param vpc_props: Properties to override default properties if deployVpc is true.
@@ -245,7 +245,7 @@ class LambdaToS3Props:
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketProps]:
-        '''Optional user provided props to override the default props for the S3 Bucket.
+        '''Optional user provided props to override the default props for the S3 Bucket, providing both this and ``existingBucketObj`` will cause an error.
 
         :default: - Default props are used
         '''
@@ -263,7 +263,9 @@ class LambdaToS3Props:
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
-        '''Existing instance of S3 Bucket object, providing both this and ``bucketProps`` will cause an error.
+        '''Optional - existing instance of S3 Bucket.
+
+        If this is provided, then also providing bucketProps causes an error.
 
         :default: - None
         '''
@@ -274,7 +276,7 @@ class LambdaToS3Props:
     def existing_lambda_obj(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
-        '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
+        '''Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
@@ -291,7 +293,10 @@ class LambdaToS3Props:
     def lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''Optional user provided props to override the default props for the Lambda function.
+        '''Optional - user provided props to override the default props for the Lambda function.
+
+        Providing both this and ``existingLambdaObj``
+        causes an error.
 
         :default: - Default properties are used.
         '''
